#include "tao/Adapter.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Adapter::~TAO_Adapter ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
